sycli

package module
v0.0.0-...-d24275a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 6, 2020 License: MIT Imports: 2 Imported by: 0

README

sycli

Stream audio from youtube livestreams in the command line.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SendCommand

func SendCommand(cmd Command, conn net.Conn) (int, error)

Send a Command to the mpv unix socket

Types

type Command

type Command struct {
	CommandName string
	Params      []interface{}
}

func SetBoolPropertyCommand

func SetBoolPropertyCommand(property string, val bool) Command

Utility function for quickly creating Command structs for setting a boolean property of the player

func SetIntPropertyCommand

func SetIntPropertyCommand(property string, val int) Command

Utility function for quickly creating Command structs for setting an integer property of the player

func (Command) MarshalJSON

func (c Command) MarshalJSON() ([]byte, error)

type ReceiveWrapper

type ReceiveWrapper struct {
	Error     string      `json:"error"`
	RequestID int         `json:"request_id"`
	Data      interface{} `json:"data"`
}

type SendWrapper

type SendWrapper struct {
	Command   Command `json:"command"`
	RequestID int     `json:"request_id,omitempty"`
	Async     bool    `json:"async,omitempty"`
}

Directories

Path Synopsis

Jump to