Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Command ¶
type Command struct {
CommandName string
Params []interface{}
}
func SetBoolPropertyCommand ¶
Utility function for quickly creating Command structs for setting a boolean property of the player
func SetIntPropertyCommand ¶
Utility function for quickly creating Command structs for setting an integer property of the player
func (Command) MarshalJSON ¶
type ReceiveWrapper ¶
type SendWrapper ¶
Click to show internal directories.
Click to hide internal directories.